{#- OZI
# ozi/templates/tests/new_test.j2
# SPDX-License-Identifier: MIT-0
-#}
{{ '# noqa: INP001' }}
{% for line in project.copyright_head.split('\n') %}{{ '# ' ~ line }}
{% endfor %}
{%- include user_template ignore missing %}

