{#- OZI
# ozi/templates/project.name/new_ext.pyx.j2
# SPDX-License-Identifier: MIT-0
-#}
{% for line in project.copyright_head.split('\n') %}{{ '# ' ~ line }}
{% endfor %}
{%- include user_template ignore missing %}

