{#- OZI
# ozi/templates/tests/meson.build.j2
# SPDX-License-Identifier: MIT-0
-#}
{% for line in project.copyright_head.split('\n') %}{{ '# ' ~ line }}
{% endfor -%}
{{ '# DO NOT EDIT BY HAND - This file was generated for use with OZI tools.' }}
{{ '# ozi-fix -> meson rewrite is the standard editing pipeline.' }}
test_files = ['ozi.phony']
foreach file: test_files
    if file != 'ozi.phony'
        fs.copyfile(file)
        if not meson.is_subproject() or get_option('install-subprojects').enabled()
            python.install_sources(file, subdir: '{{ project.name|underscorify|lower }}' / 'tests')
        endif
    endif
endforeach
test_children = ['ozi.phony']
foreach child: test_children
    if child != 'ozi.phony'
        subdir(child)
    endif
endforeach
if false
    executable('test_files', test_files)
    executable('test_children', test_children)
endif
